
## CATO-CLI - mutation.policy.antiMalwareFileHash.createPolicyRevision:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.policy.antiMalwareFileHash.createPolicyRevision) for documentation on this operation.

### Usage for mutation.policy.antiMalwareFileHash.createPolicyRevision:

`catocli mutation policy antiMalwareFileHash createPolicyRevision -h`

`catocli mutation policy antiMalwareFileHash createPolicyRevision <json>`

`catocli mutation policy antiMalwareFileHash createPolicyRevision "$(cat < mutation.policy.antiMalwareFileHash.createPolicyRevision.json)"`

`catocli mutation policy antiMalwareFileHash createPolicyRevision '{"antiMalwareFileHashPolicyMutationInput":{"policyMutationRevisionInput":{"id":"id"}},"policyCreateRevisionInput":{"description":"string","name":"string"}}'`


#### Operation Arguments for mutation.policy.antiMalwareFileHash.createPolicyRevision ####

`accountId` [ID] - (required) N/A    
`antiMalwareFileHashPolicyMutationInput` [AntiMalwareFileHashPolicyMutationInput] - (required) N/A    
`policyCreateRevisionInput` [PolicyCreateRevisionInput] - (required) N/A    
